package TableData::Test::Source::DBI;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-06-01'; # DATE
our $DIST = 'TableDataRoles-Standard'; # DIST
our $VERSION = '0.009'; # VERSION

use alias::module 'TableData::DBI';

1;
# ABSTRACT: Alias package for TableData::DBI

__END__

=pod

=encoding UTF-8

=head1 NAME

TableData::Test::Source::DBI - Alias package for TableData::DBI

=head1 VERSION

This document describes version 0.009 of TableData::Test::Source::DBI (from Perl distribution TableDataRoles-Standard), released on 2021-06-01.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/TableDataRoles-Standard>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-TableDataRoles-Standard>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableDataRoles-Standard>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<TableData::DBI>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
